from distutils.core import setup
setup(
  name = 'allezup',
  packages = ['allezup'],
  version = '0.1',
  description = 'add directories above that of the source file to the python path',
  author = 'Marc Burns',
  author_email = 'm4burns@uwaterloo.ca',
  url = 'https://github.com/m4burns/allezup',
  download_url = 'https://github.com/m4burns/allezup/archive/0.1.tar.gz',
  keywords = ['module', 'package', 'import', 'path'],
  classifiers = [],
)
